@@ -5,7 +5,7 @@ from gpaw.xc.libvdwxc import libvdwxc_has_pfft
 def create_tasks():
     jobs = []
     if compiled_with_libvdwxc():
-        jobs.apend(task('libvdwxc-example.py'))
+        jobs.append(task('libvdwxc-example.py'))
         if libvdwxc_has_pfft():
             jobs.append(task('libvdwxc-pfft-example.py', cores=8))
     return jobs
