@@ -12,7 +12,7 @@ def create_tasks():
         task('Fe_gs.py@4:20m'),
         task('Fe_bands.py@32:1h', deps='Fe_gs.py'),
         task('plot_Fe_bands.py@1:10m', deps='Fe_bands.py'),
-        task('gs_Bi2Se3.py@4:40m'),
+        task('gs_Bi2Se3.py@4:2h'),
         task('Bi2Se3_bands.py@32:5h', deps='gs_Bi2Se3.py'),
         task('high_sym.py@4:30h', deps='gs_Bi2Se3.py'),
         task('parity.py@1:5h', deps='high_sym.py'),
