@@ -32,7 +32,7 @@ alpha = 1 / 137.036
 class AllElectron:
     """Object for doing an atomic DFT calculation."""
 
-    def __init__(self, symbol, xcname='LDA', scalarrel=False,
+    def __init__(self, symbol, xcname='LDA', scalarrel=True,
                  corehole=None, configuration=None, nofiles=True,
                  txt='-', gpernode=150, orbital_free=False, tw_coeff=1.):
         """Do an atomic DFT calculation.
@@ -42,7 +42,7 @@ class AllElectron:
           a = AllElectron('Fe')
           a.run()
         """
-        
+
         if txt is None:
             txt = devnull
         elif txt == '-':
@@ -107,7 +107,7 @@ class AllElectron:
             self.f_j = [self.Z]
             self.e_j = [self.e_j[-1]]
 
-            
+
         t = self.text
         t()
         if scalarrel:
@@ -155,7 +155,7 @@ class AllElectron:
             u[:] = r**(1 + l) * np.exp(-a * r)
             norm = np.dot(u**2, dr)
             u *= 1.0 / sqrt(norm)
-            
+
     def run(self, use_restart_file=True):
         #     beta g
         # r = ------, g = 0, 1, ..., N - 1
@@ -194,12 +194,12 @@ class AllElectron:
         if self.xc.type == 'GLLB':
             self.xc.pass_stuff_1d(self)
             self.xc.initialize_1d()
-            
+
         n_j = self.n_j
         l_j = self.l_j
         f_j = self.f_j
         e_j = self.e_j
-        
+
         Z = self.Z    # nuclear charge
         r = self.r    # radial coordinate
         dr = self.dr  # dr/dg
@@ -240,12 +240,12 @@ class AllElectron:
 
         bar = '|------------------------------------------------|'
         t(bar)
-        
+
         niter = 0
         nitermax = 117
         qOK = log(1e-10)
         mix = 0.4
-        
+
         # orbital_free needs more iterations and coefficient
         if self.orbital_free:
             mix = 0.01
@@ -254,9 +254,9 @@ class AllElectron:
             if Z > 10 : #help convergence for third row elements
                 mix = 0.002
                 nitermax = 10000
-            
+
         vrold = None
-        
+
         while True:
             # calculate hartree potential
             hartree(0, n * r * dr, r, vHr)
@@ -333,16 +333,16 @@ class AllElectron:
                 pass
 
         Ekin = 0
-        
+
         for f, e in zip(f_j, e_j):
             Ekin += f * e
 
-        Epot = 2 * pi * np.dot(n * r * (vHr - Z), dr)
+        e_coulomb = 2 * pi * np.dot(n * r * (vHr - Z), dr)
         Ekin += -4 * pi * np.dot(n * vr * r, dr)
 
         if self.orbital_free:
-        #e and vr are not scaled back
-        #instead Ekin is scaled for total energy (printed and inside setup)
+            # e and vr are not scaled back
+            # instead Ekin is scaled for total energy (printed and inside setup)
             Ekin *= self.tw_coeff
             t()
             t('Lambda:{0}'.format(self.tw_coeff))
@@ -354,10 +354,10 @@ class AllElectron:
         t('-------------------------')
         t('Kinetic:   %+13.6f' % Ekin)
         t('XC:        %+13.6f' % Exc)
-        t('Potential: %+13.6f' % Epot)
+        t('Potential: %+13.6f' % e_coulomb)
         t('-------------------------')
-        t('Total:     %+13.6f' % (Ekin + Exc + Epot))
-        self.ETotal = Ekin + Exc + Epot
+        t('Total:     %+13.6f' % (Ekin + Exc + e_coulomb))
+        self.ETotal = Ekin + Exc + e_coulomb
         t()
 
         t('state      eigenvalue         ekin         rmax')
@@ -393,7 +393,7 @@ class AllElectron:
         self.write(tau, 'tau')
 
         self.Ekin = Ekin
-        self.Epot = Epot
+        self.e_coulomb = e_coulomb
         self.Exc = Exc
 
     def write(self, array, name=None, n=None, l=None):
@@ -590,7 +590,7 @@ class AllElectron:
 
     def solve_confined(self, j, rc, vconf=None):
         """Solve the Schroedinger equation in a confinement potential.
-        
+
         Solves the Schroedinger equation like the solve method, but with a
         number of differences.  Before invoking this method, run solve() to
         get initial guesses.
@@ -621,11 +621,11 @@ class AllElectron:
             l = self.l_j[j]
             e = self.e_j[j]
             u = self.u_j[j].copy()
-            
+
         nn, A = shoot_confined(u, l, vr, e, self.r2dvdr, r, dr, c10, c2,
                                self.scalarrel, rc=rc, beta=self.beta)
         assert nn == n - l - 1  # run() should have been called already
-        
+
         # adjust eigenenergy until u is smooth at the turning point
         de = 1.0
         while abs(de) > 1e-9:
@@ -672,8 +672,8 @@ class AllElectron:
         return int(r * self.N / (self.beta + r))
 
     def get_confinement_potential(self, alpha, ri, rc):
-        """Create a smooth confinement potential.
-        
+        r"""Create a smooth confinement potential.
+
         Returns a (potential) function which is zero inside the radius ri
         and goes to infinity smoothly at rc, after which point it is nan.
         The potential is given by::
@@ -701,7 +701,7 @@ class AllElectron:
         return alpha * potential
 
 
-def shoot(u, l, vr, e, r2dvdr, r, dr, c10, c2, scalarrel=False, gmax=None):
+def shoot(u, l, vr, e, r2dvdr, r, dr, c10, c2, scalarrel, gmax=None):
     """n, A = shoot(u, l, vr, e, ...)
 
     For guessed trial eigenenergy e, integrate the radial Schrodinger
@@ -787,8 +787,9 @@ def shoot(u, l, vr, e, r2dvdr, r, dr, c10, c2, scalarrel=False, gmax=None):
     # perform forward integration from zero to the turning point
     g = 1
     nodes = 0
-    while g <= gtp:  # integrate one step further than gtp
-                     # (such that dudr is defined in gtp)
+    # integrate one step further than gtp
+    # (such that dudr is defined in gtp)
+    while g <= gtp:
         u[g + 1] = (fm[g] * u[g - 1] - f0[g] * u[g]) / fp[g]
         if u[g + 1] * u[g] < 0:
             nodes += 1
@@ -806,7 +807,7 @@ def shoot(u, l, vr, e, r2dvdr, r, dr, c10, c2, scalarrel=False, gmax=None):
     return nodes, A
 
 
-def shoot_confined(u, l, vr, e, r2dvdr, r, dr, c10, c2, scalarrel=False,
+def shoot_confined(u, l, vr, e, r2dvdr, r, dr, c10, c2, scalarrel,
                    gmax=None, rc=10., beta=7.):
     """This method is used by the solve_confined method."""
     # XXX much of this is pasted from the ordinary shoot method
@@ -844,7 +845,7 @@ guess for the density).
         # perform backwards integration from infinity to the turning point
         g = gcut - 2
         u[g] = u[g + 1] * f0[g + 1] / fm[g + 1]
-        
+
         while c0[g] > 0.0:  # this defines the classical turning point
             u[g - 1] = (f0[g] * u[g] + fp[g] * u[g + 1]) / fm[g]
             if u[g - 1] < 0.0:
@@ -871,8 +872,9 @@ guess for the density).
     # perform forward integration from zero to the turning point
     g = 1
     nodes = 0
-    while g <= gtp:  # integrate one step further than gtp
-                     # (such that dudr is defined in gtp)
+    # integrate one step further than gtp
+    # (such that dudr is defined in gtp)
+    while g <= gtp:
         u[g + 1] = (fm[g] * u[g - 1] - f0[g] * u[g]) / fp[g]
         if u[g + 1] * u[g] < 0:
             nodes += 1
