@@ -7,13 +7,15 @@ from ase.units import Bohr, Hartree
 
 import _gpaw
 
-__all__ = ['ConstantPotential', 'ConstantElectricField']
+__all__ = ['ConstantPotential', 'ConstantElectricField', 'CDFTPotential']
 
 
 def create_external_potential(name, **kwargs):
     """Construct potential from dict."""
     if name not in __all__:
         raise ValueError
+    if name == 'CDFTPotential':
+        return None
     return globals()[name](**kwargs)
 
 
@@ -46,11 +48,15 @@ class ExternalPotential:
     def calculate_potential(self, gd):
         raise NotImplementedError
 
+    def get_name(self):
+        return self.__class__.__name__
+
 
 class ConstantPotential(ExternalPotential):
     """Constant potential for tests."""
     def __init__(self, constant=1.0):
         self.constant = constant / Hartree
+        self.name = 'ConstantPotential'
 
     def __str__(self):
         return 'Constant potential: {:.3f} V'.format(self.constant * Hartree)
@@ -59,7 +65,7 @@ class ConstantPotential(ExternalPotential):
         self.vext_g = gd.zeros() + self.constant
 
     def todict(self):
-        return {'name': 'ConstantPotential',
+        return {'name': self.name,
                 'constant': self.constant * Hartree}
 
 
@@ -75,6 +81,7 @@ class ConstantElectricField(ExternalPotential):
         d_v = np.asarray(direction)
         self.field_v = strength * d_v / (d_v**2).sum()**0.5 * Bohr / Hartree
         self.tolerance = tolerance
+        self.name = 'ConstantElectricField'
 
     def __str__(self):
         return ('Constant electric field: '
@@ -96,7 +103,7 @@ class ConstantElectricField(ExternalPotential):
 
     def todict(self):
         strength = (self.field_v**2).sum()**0.5
-        return {'name': 'ConstantElectricField',
+        return {'name': self.name,
                 'strength': strength * Hartree / Bohr,
                 'direction': self.field_v / strength}
 
@@ -191,3 +198,8 @@ class PointChargePotential(ExternalPotential):
                            self.vext_g, dcom_pv, dens.rhot_g, F_pv)
         gd.comm.sum(F_pv)
         return F_pv * Hartree / Bohr
+
+class CDFTPotential(ExternalPotential):
+    # Dummy class to make cDFT compatible with new external potential class ClassName(object):
+    def __init__(self):
+        self.name = 'CDFTPotential'
