@@ -24,7 +24,7 @@ def get_rot(F_MM, V_oM, L):
         col1 /= norm
         col2 /= norm
     return U_ow, U_lw, U_Ml
-    
+
 
 def get_lcao_xc(calc, P_aqMi, bfs=None, spin=0):
     nq = len(calc.wfs.kd.ibzk_qc)
@@ -32,7 +32,7 @@ def get_lcao_xc(calc, P_aqMi, bfs=None, spin=0):
     dtype = calc.wfs.dtype
     if bfs is None:
         bfs = get_bfs(calc)
-    
+
     if calc.density.nt_sg is None:
         calc.density.interpolate_pseudo_density()
     nt_sg = calc.density.nt_sg
@@ -71,7 +71,7 @@ def get_xc2(calc, w_wG, P_awi, spin=0):
     xc_ww = np.empty((Nw, Nw))
     r2k(.5 * calc.wfs.gd.dv, w_wG, vxct_G * w_wG, .0, xc_ww)
     tri2full(xc_ww, 'L')
-    
+
     # Add atomic PAW corrections
     for a, P_wi in P_awi.items():
         D_sp = calc.density.D_asp[a][:]
@@ -87,7 +87,7 @@ class ProjectedWannierFunctionsFBL:
     """PWF in the finite band limit.
 
     ::
-    
+
                 --N
         |w_w> = >    |psi_n> U_nw
                 --n=1
@@ -95,7 +95,7 @@ class ProjectedWannierFunctionsFBL:
     def __init__(self, V_nM, No, ortho=False):
         Nw = V_nM.shape[1]
         assert No <= Nw
-        
+
         V_oM, V_uM = V_nM[:No], V_nM[No:]
         F_MM = np.dot(V_uM.T.conj(), V_uM)
         U_ow, U_lw, U_Ml = get_rot(F_MM, V_oM, Nw - No)
@@ -129,7 +129,7 @@ class ProjectedWannierFunctionsIBL:
     """PWF in the infinite band limit.
 
     ::
-    
+
                 --No               --Nw
         |w_w> = >   |psi_o> U_ow + >   |f_M> U_Mw
                 --o=1              --M=1
@@ -138,7 +138,7 @@ class ProjectedWannierFunctionsIBL:
         Nw = V_nM.shape[1]
         assert No <= Nw
         self.V_oM, V_uM = V_nM[:No], V_nM[No:]
-        
+
         F_MM = S_MM - np.dot(self.V_oM.T.conj(), self.V_oM)
         U_ow, U_lw, U_Ml = get_rot(F_MM, self.V_oM, Nw - No)
         self.U_Mw = np.dot(U_Ml, U_lw)
@@ -198,7 +198,7 @@ class PWFplusLCAO(ProjectedWannierFunctionsIBL):
         Nw = V_nM.shape[1]
         self.V_oM = V_nM[:No]
         dtype = V_nM.dtype
-        
+
         # Do PWF optimization for pwfbasis submatrix only!
         Npwf = len(pwfmask.nonzero()[0])
         pwfmask2 = np.outer(pwfmask, pwfmask)
@@ -207,7 +207,7 @@ class PWFplusLCAO(ProjectedWannierFunctionsIBL):
         f_MM = s_MM - np.dot(v_oM.T.conj(), v_oM)
         nw = len(s_MM)
         assert No <= nw
-        
+
         u_ow, u_lw, u_Ml = get_rot(f_MM, v_oM, nw - No)
         u_Mw = np.dot(u_Ml, u_lw)
         u_ow = u_ow - np.dot(v_oM, u_Mw)
@@ -228,7 +228,7 @@ class PWFplusLCAO(ProjectedWannierFunctionsIBL):
         self.S_ww = self.rotate_matrix(np.ones(1), S_MM)
         self.norms_n = None
 
-    
+
 class PWF2:
     def __init__(self, gpwfilename, fixedenergy=0., spin=0, ibl=True,
                  basis='sz', zero_fermi=False, pwfbasis=None, lcaoatoms=None,
@@ -326,8 +326,9 @@ class PWF2:
                     dict([(a, P_qMi[q]) for a, P_qMi in self.P_aqMi.items()]),
                     indices)
             else:
+                assert 0
                 # XXX pwf?
-                self.P_awi = pwf.rotate_projections(kpt.P_ani, indices)
+                # self.P_awi = pwf.rotate_projections(kpt.P_ani, indices)
         return self.P_awi
 
     def get_orbitals(self, q=0, indices=None):
@@ -375,7 +376,7 @@ class LCAOwrap:
         assert calc.wfs.gd.comm.size == 1
         assert calc.wfs.kd.comm.size == 1
         assert calc.wfs.bd.comm.size == 1
-        
+
         from gpaw.lcao.tools import get_lcao_hamiltonian
         H_skMM, S_kMM = get_lcao_hamiltonian(calc)
 
@@ -386,10 +387,10 @@ class LCAOwrap:
         self.S_qww = S_kMM
         self.P_aqwi = calc.wfs.P_aqMi
         self.Nw = self.S_qww.shape[-1]
-        
+
         for S in self.S_qww:
             print('Condition number: %0.1e' % condition_number(S))
-    
+
     def get_hamiltonian(self, q=0, indices=None):
         if indices is None:
             return self.H_qww[q]
