@@ -29,6 +29,7 @@ import sys
 
 
 cmds = """\
+pip install --upgrade pip
 touch gpaw-tests.lock
 cd ase; git pull -q; pip install -U .
 cd gpaw; git clean -fdx; git pull -q
@@ -36,7 +37,7 @@ cd gpaw; python setup.py install {} 2> ../test.err
 gpaw test > test-1.out
 gpaw -P 2 test > test-2.out
 gpaw -P 4 test > test-4.out
-gpaw -P 8 test > test-8.out
+mpiexec -np 8 --oversubscribe gpaw-python -m gpaw test > test-8.out
 grep -i fail test-?.out >&2 || echo OK"""
 # grep return error code 1 if nothing found.  So we end with "echo OK" to get
 # a zero error code.
