@@ -228,7 +228,6 @@ class PWDescriptor:
         self.maxmyng = (self.ngmax + S - 1) // S
         ng1 = gd.comm.rank * self.maxmyng
         ng2 = ng1 + self.maxmyng
-        assert ng1 <= self.ngmin
 
         self.G2_qG = []
         self.myQ_qG = []
@@ -406,11 +405,11 @@ class PWDescriptor:
         ssize_r[:N] = self.myng_q[q]
         soffset_r = np.arange(comm.size) * self.myng_q[q]
         soffset_r[N:] = 0
+        roffset_r = (np.arange(comm.size) * self.maxmyng).clip(max=ng)
         rsize_r = np.zeros(comm.size, int)
         if comm.rank < N:
-            rsize_r[:-1] = self.maxmyng
-            rsize_r[-1] = ng - self.maxmyng * (comm.size - 1)
-        roffset_r = np.arange(0, ng, self.maxmyng)
+            rsize_r[:-1] = roffset_r[1:] - roffset_r[:-1]
+            rsize_r[-1] = ng - roffset_r[-1]
         b_G = self.tmp_G[:ng]
         comm.alltoallv(a_rG, ssize_r, soffset_r, b_G, rsize_r, roffset_r)
         if comm.rank < N:
@@ -428,11 +427,11 @@ class PWDescriptor:
         rsize_r[:N] = self.myng_q[q]
         roffset_r = np.arange(comm.size) * self.myng_q[q]
         roffset_r[N:] = 0
+        soffset_r = (np.arange(comm.size) * self.maxmyng).clip(max=ng)
         ssize_r = np.zeros(comm.size, int)
         if comm.rank < N:
-            ssize_r[:-1] = self.maxmyng
-            ssize_r[-1] = ng - self.maxmyng * (comm.size - 1)
-        soffset_r = np.arange(0, ng, self.maxmyng)
+            ssize_r[:-1] = soffset_r[1:] - soffset_r[:-1]
+            ssize_r[-1] = ng - soffset_r[-1]
         tmp_rG = self.tmp_G[:b_rG.size].reshape(b_rG.shape)
         comm.alltoallv(a_G, ssize_r, soffset_r, tmp_rG, rsize_r, roffset_r)
         b_rG += tmp_rG
@@ -458,8 +457,14 @@ class PWDescriptor:
             assert self.dtype == float and self.gd.comm.size == 1
             return a_xg[..., 0].real * self.gd.dv
 
-        A_xg = a_xg.reshape((-1, a_xg.shape[-1]))
-        B_yg = b_yg.reshape((-1, b_yg.shape[-1]))
+        if a_xg.ndim == 1:
+            A_xg = a_xg.reshape((1, len(a_xg)))
+        else:
+            A_xg = a_xg
+        if b_yg.ndim == 1:
+            B_yg = b_yg.reshape((1, len(b_yg)))
+        else:
+            B_yg = b_yg
 
         alpha = self.gd.dv / self.gd.N_c.prod()
 
@@ -1250,12 +1255,14 @@ class PWWaveFunctions(FDPWWaveFunctions):
                 dist=(self.bd.comm, -1, 1),
                 spin=kpt.s, collinear=self.collinear)
             psit_nG = kpt.psit.array
-            for n, psit_G in enumerate(psit_nG.reshape((-1,
-                                                        psit_nG.shape[-1]))):
+            if psit_nG.ndim == 3:
+                N, S, G = psit_nG.shape
+                psit_nG = psit_nG.reshape((N * S, G))
+            for n, psit_G in enumerate(psit_nG):
                 psit_nR[:] = 0.0
-                basis_functions.lcao_to_grid(kpt.C_nM[n:n + 1], psit_nR, kpt.q)
+                basis_functions.lcao_to_grid(kpt.C_nM[n:n + 1],
+                                             psit_nR, kpt.q)
                 psit_G[:] = self.pd.fft(psit_nR[0] * emikr_R, kpt.q)
-
             kpt.C_nM = None
 
     def random_wave_functions(self, mynao):
@@ -1557,8 +1564,9 @@ class PWLFC(BaseLFC):
             if self.comm.size != 1:
                 self.comm.sum(c_xI)
 
-        c_xI = c_xI.reshape((np.prod(c_xI.shape[:-1], dtype=int), self.nI))
-        a_xG = a_xG.reshape((-1, a_xG.shape[-1])).view(self.pd.dtype)
+        nx = np.prod(c_xI.shape[:-1], dtype=int)
+        c_xI = c_xI.reshape((nx, self.nI))
+        a_xG = a_xG.reshape((nx, a_xG.shape[-1])).view(self.pd.dtype)
 
         for G1, G2 in self.block(q):
             if f0_IG is None:
@@ -1578,8 +1586,9 @@ class PWLFC(BaseLFC):
     def integrate(self, a_xG, c_axi=None, q=-1):
         c_xI = np.zeros(a_xG.shape[:-1] + (self.nI,), self.pd.dtype)
 
-        b_xI = c_xI.reshape((np.prod(c_xI.shape[:-1], dtype=int), self.nI))
-        a_xG = a_xG.reshape((-1, a_xG.shape[-1]))
+        nx = np.prod(c_xI.shape[:-1], dtype=int)
+        b_xI = c_xI.reshape((nx, self.nI))
+        a_xG = a_xG.reshape((nx, a_xG.shape[-1]))
 
         alpha = 1.0 / self.pd.gd.N_c.prod()
         if self.pd.dtype == float:
@@ -1754,6 +1763,8 @@ class ReciprocalSpaceDensity(Density):
                          redistributor=redistributor,
                          background_charge=background_charge)
 
+        ecut0 = 0.5 * pi**2 / (gd.h_cv**2).sum(1).max()
+        ecut = min(ecut, ecut0)
         self.pd2 = PWDescriptor(ecut, gd)
         self.pd3 = PWDescriptor(4 * ecut, finegd)
 
